@@ -139,8 +139,7 @@ This will delete all the documents which contain the passed term.
 sub delete_term {
 	my ($self, $term) = @_;
 	my $enum = $self->term_docs($term);
-	$self->delete($enum->doc);
-	$self->delete($enum->doc) while $enum->next;
+	do { $self->delete($enum->doc) } until (!$enum->next);
 }
 
 =head2 close
